@@ -7,7 +7,7 @@
 
 class Font_ttf{
 public:
-	static unsigned int Font_ttf::gen_dl(std::string fontname,unsigned int size,C3 col=C3(255,255,255));
+	static unsigned int gen_dl(std::string fontname,unsigned int size,C3 col=C3(255,255,255));
 	static int dx();
 	static int dy();
 };
