@@ -1,6 +1,8 @@
 
-class el3::Random;
-class el3::Mapbase;
+namespace el3 {
+class Random;
+class Mapbase;
+}
 
 void intreg1(el3::Mapbase *m,el3::Random *rg);
 void stromtest1(el3::Mapbase *m,el3::Random *rg);
