@@ -24,7 +24,7 @@ public:
 	unsigned int dz();
 
 
-	bool Map::inside(C3 c);
+	bool inside(C3 c);
 	
 	e_tiletype get(C3);
 	void set(C3,e_tiletype);
