@@ -1,8 +1,8 @@
 
 
 #define PRJID el3
-#define VERSION "1.2"
+#define VERSION "1.25"
 #define FULLNAME "enemy lines 3"
 #define SHORTNAME "el3"
 #define PATHNAME "enemylines3"
-#define EL_URL "http://raum1.memebot.com/enemylines/"
+#define EL_URL "http://proj.phk.at/el/"
